@@ -100,6 +100,10 @@ sub new {
                 other_language_codes => \%language_codes,
                 tt      => Template::Tiny->new,
                 templates => Text::Amuse::Compile::Templates->new,
+                font_script => $docs[0]->font_script,
+                html_direction => $docs[0]->html_direction,
+                is_rtl => $docs[0]->is_rtl,
+                is_bidi => scalar(grep { $_->is_rtl || $_->is_bidi } @docs),
                };
     bless $self, $class;
 }
@@ -126,6 +130,22 @@ language codes, undef otherwise.
 
 Return the hyphenation of the first text.
 
+=head2 font_script
+
+The font script of the first text.
+
+=head2 html_direction
+
+The direction (rtl or ltr) of the first text
+
+=head2 is_rtl
+
+Return true if the first text is RTL.
+
+=head2 is_bidi
+
+Return true if any of the text is RTL or bidirectional.
+
 =cut
 
 sub language {
@@ -162,15 +182,33 @@ sub other_languages {
     }
 }
 
+sub font_script {
+    return shift->{font_script};
+}
+
+sub is_bidi {
+    return shift->{is_bidi};
+}
+
+sub html_direction {
+    return shift->{html_direction};
+}
+sub is_rtl {
+    return shift->{is_rtl};
+}
 
 =head2 as_splat_html
 
 Return a list of HTML fragments.
 
+=head2 as_splat_html_with_attrs
+
+Return a list of tokens for the minimal html template
+
 =cut
 
-sub as_splat_html {
-    my $self = shift;
+sub _as_splat_html {
+    my ($self, %opts) = @_;
     my @out;
     my $counter = 0;
     foreach my $doc ($self->docs) {
@@ -190,11 +228,30 @@ sub as_splat_html {
                             |id=")
                             text-amuse-label)/$1-$prefix/gx;
         }
-        push @out, $title_page, @pieces;
+        if ($opts{attrs}) {
+            push @out, map {
+                +{
+                  text => $_,
+                  language_code => $doc->language_code,
+                  html_direction => $doc->html_direction,
+                 }
+            } ($title_page, @pieces);
+        }
+        else {
+            push @out, $title_page, @pieces;
+        }
     }
     return @out;
 }
 
+sub as_splat_html_with_attrs {
+    return shift->_as_splat_html(attrs => 1);
+}
+
+sub as_splat_html {
+    return shift->_as_splat_html;
+}
+
 =head2 raw_html_toc
 
 Implements the C<raw_html_toc> from L<Text::Amuse>
